bayespy.inference.vmp.nodes.gaussian.GaussianGammaDistribution.compute_weights_to_parent
========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaDistribution.compute_weights_to_parent